==> nui_core-0.0.138.tar.gz: lib/string/nui_string_util.dart <==
//Created by Neo on 19th Aug 2020
import 'package:intl/intl.dart';
import 'package:nui_core/code/nui_code_util.dart';
import 'package:nui_core/data/nui_data_util.dart';
import 'package:uuid/uuid.dart';

extension StringExtension on String {
  String capitalize() => "${this[0].toUpperCase()}${this.substring(1)}";
  bool isNullOrEmpty() => this == null || this.isEmpty;
  bool isNotNullOrEmpty() => this != null && this.isNotEmpty;
  match(String value) => NUIStringUtil.match(this, value);
  contains(String value) => NUIStringUtil.contains(this, value);
}

String formatNumber(dynamic number, {bool showComma: true, int decimals: 2}) {
  return NUIStringUtil.formatNumber(number, showComma: showComma, decimals: decimals);
}

bool match(String value1, String value2){
  return NUIStringUtil.match(value1, value2);
}

int matchSearch({String keyword, List<String> criterias}){
  return NUIStringUtil.matchSearch(keyword: keyword, criterias: criterias);
}

bool contains(String value1, String value2){
  return value1.contains(value2);
}

String randomUUID(){
  return NUIStringUtil.randomUUID();
}

class NUIStringUtil{
  static const FILLED_DOT = "\u2022";

  NUIStringUtil._builder();

  static String randomUUID(){
    return Uuid().v1();
  }

  static int matchSearch({String keyword, List<String> criterias}){
    if(keyword.isNullOrEmpty() || isNullOrEmpty(criterias)) return 0;
    int matchWeight = 0;
    List<String> splittedKeywords = keyword.toLowerCase().trim().split(RegExp(" "));
    criterias.forEach((element) {
      splittedKeywords.forEach((key) {
        if(!key.isNullOrEmpty() && contains(element, key)){
          matchWeight++;
        }
      });
    });
    return matchWeight;
  }

  static String splitByComma(List<String> values, {String separator: ", "}){
    String value = "";
    loop(values, (data, position, isFirst, isLast){
      if(!isNullOrEmpty(data)) {
        value = value + (isNullOrEmpty(value) ? data : (separator + data));
      }
    });
    return value;
  }

  static String formatNumber(dynamic number, {bool showComma: true, int decimals: 2}){
    if(number == null) return null;

    var frontFormat = "#,###";
    if(!showComma) frontFormat = "#";

    var decimalFormat = "";
    for(int i = 0; i< decimals; i++){
      if(decimalFormat.isEmpty){
        decimalFormat = ".";
      }
      decimalFormat = decimalFormat + "#";
    }
    final format = frontFormat + decimalFormat;
    return NumberFormat(format).format(number);
  }

  static String formatNRICMY(String nric) {
    var value = nric.trim();
    value = value.replaceAll("-", "");

    if(value.length == 12){
      var firstPart = value.substring(0, 6);
      var secondPart = value.substring(6, 8);
      var thirdPart = value.substring(8, 12);

      return firstPart + "-" + secondPart + "-" + thirdPart;
    }
    return nric;
  }

  static getDottedString(List<String> values) {
    var dottedString = "";
    for(String value in values){
      if(dottedString.isEmpty){
        dottedString = dottedString + value;
      }
      else{
        dottedString = dottedString + " " + FILLED_DOT + " " + value;
      }
    }
    return dottedString;
  }

  static bool match(String value1, String value2){
    return value1 != null && value2 != null && value1.toLowerCase() == value2.toLowerCase();
  }

  static bool validateStringPattern(String value, String pattern, {bool fullMatch: true}){
    if(value.isNullOrEmpty() || pattern.isNullOrEmpty() || match(pattern, "any")){
      return true;
    }
    print("NUIStringUtil -> Validating string pattern of $pattern");
    var p = RegExp(pattern);

    if(!fullMatch) {
      final hasMatch = p.hasMatch(value);
      print("NUIStringUtil -> Validating string pattern of $pattern returns hasMatch : $hasMatch");
      return hasMatch;
    }
    else{
      try {
        final matches = p.allMatches(value);
        for (Match match in matches) {
          if (match.start == 0 && match.end == value.length) {
            return true;
          }
        }
        return false;
      }catch(e){
        return true;
      }
    }
  }

  static bool contains(String value, String keyword){
    if(NUIDataUtil.isNullOrEmpty(value)) return false;
    if(NUIDataUtil.isNullOrEmpty(keyword)) return true;
    return value.toLowerCase().contains(keyword.toLowerCase());
  }

  static String ellipseEnd(String value, int maxLength, {String ellipseText : "...", bool appendEllipse : true}){
    int endIndex;
    if(value.length >= maxLength){
      endIndex = maxLength;
    }
    else{
      endIndex = value.length;
    }

    var validValue = value.substring(0, endIndex).toString();

    if(appendEllipse){
      return validValue + ellipseText;
    }
    else{
      return validValue;
    }
  }

  static List<String> splitByToSmallCases(String value, String regex){
    List<String> values = value.toLowerCase().split(RegExp(regex));
    return List.of(values);
  }

}

==> nui_core-0.0.144.tar.gz: lib/string/nui_string_util.dart <==
//Created by Neo on 19th Aug 2020
import 'package:intl/intl.dart';
import 'package:nui_core/code/nui_code_util.dart';
import 'package:nui_core/data/nui_data_util.dart';
import 'package:uuid/uuid.dart';

extension StringExtension on String {
  String capitalize() => "${this[0].toUpperCase()}${this.substring(1)}";
  bool isNullOrEmpty() => this == null || this.isEmpty;
  bool isNotNullOrEmpty() => this != null && this.isNotEmpty;
  match(String value) => NUIStringUtil.match(this, value);
  contains(String value) => NUIStringUtil.contains(this, value);
}

String formatNumber(dynamic number, {bool showComma: true, int decimals: 2, bool fixedDecimal: true}) {
  return NUIStringUtil.formatNumber(number, showComma: showComma, decimals: decimals, fixedDecimal: fixedDecimal);
}

bool match(String value1, String value2){
  return NUIStringUtil.match(value1, value2);
}

int matchSearch({String keyword, List<String> criterias}){
  return NUIStringUtil.matchSearch(keyword: keyword, criterias: criterias);
}

bool contains(String value1, String value2){
  return value1.contains(value2);
}

String randomUUID(){
  return NUIStringUtil.randomUUID();
}

class NUIStringUtil{
  static const FILLED_DOT = "\u2022";

  NUIStringUtil._builder();

  static String randomUUID(){
    return Uuid().v1();
  }

  static int matchSearch({String keyword, List<String> criterias}){
    if(keyword.isNullOrEmpty() || isNullOrEmpty(criterias)) return 0;
    int matchWeight = 0;
    List<String> splittedKeywords = keyword.toLowerCase().trim().split(RegExp(" "));
    criterias.forEach((element) {
      splittedKeywords.forEach((key) {
        if(!key.isNullOrEmpty() && contains(element, key)){
          matchWeight++;
        }
      });
    });
    return matchWeight;
  }

  static String splitByComma(List<String> values, {String separator: ", "}){
    String value = "";
    loop(values, (data, position, isFirst, isLast){
      if(!isNullOrEmpty(data)) {
        value = value + (isNullOrEmpty(value) ? data : (separator + data));
      }
    });
    return value;
  }

  static String formatNumber(dynamic number, {bool showComma: true, int decimals: 2, bool fixedDecimal: true}){
    if(number == null) return null;

    var frontFormat = "#,###";
    if(!showComma) frontFormat = "#";

    var decimalFormat = "";
    for(int i = 0; i< decimals; i++){
      if(decimalFormat.isEmpty){
        decimalFormat = ".";
      }
      decimalFormat = decimalFormat + (fixedDecimal != true ? "#" : "0");
    }
    final format = frontFormat + decimalFormat;
    return NumberFormat(format).format(number);
  }

  static String formatNRICMY(String nric) {
    var value = nric.trim();
    value = value.replaceAll("-", "");

    if(value.length == 12){
      var firstPart = value.substring(0, 6);
      var secondPart = value.substring(6, 8);
      var thirdPart = value.substring(8, 12);

      return firstPart + "-" + secondPart + "-" + thirdPart;
    }
    return nric;
  }

  static getDottedString(List<String> values) {
    var dottedString = "";
    for(String value in values){
      if(dottedString.isEmpty){
        dottedString = dottedString + value;
      }
      else{
        dottedString = dottedString + " " + FILLED_DOT + " " + value;
      }
    }
    return dottedString;
  }

  static bool match(String value1, String value2){
    return value1 != null && value2 != null && value1.toLowerCase() == value2.toLowerCase();
  }

  static bool validateStringPattern(String value, String pattern, {bool fullMatch: true}){
    if(value.isNullOrEmpty() || pattern.isNullOrEmpty() || match(pattern, "any")){
      return true;
    }
    print("NUIStringUtil -> Validating string pattern of $pattern");
    var p = RegExp(pattern);

    if(!fullMatch) {
      final hasMatch = p.hasMatch(value);
      print("NUIStringUtil -> Validating string pattern of $pattern returns hasMatch : $hasMatch");
      return hasMatch;
    }
    else{
      try {
        final matches = p.allMatches(value);
        for (Match match in matches) {
          if (match.start == 0 && match.end == value.length) {
            return true;
          }
        }
        return false;
      }catch(e){
        return true;
      }
    }
  }

  static bool contains(String value, String keyword){
    if(NUIDataUtil.isNullOrEmpty(value)) return false;
    if(NUIDataUtil.isNullOrEmpty(keyword)) return true;
    return value.toLowerCase().contains(keyword.toLowerCase());
  }

  static String ellipseEnd(String value, int maxLength, {String ellipseText : "...", bool appendEllipse : true}){
    int endIndex;
    if(value.length >= maxLength){
      endIndex = maxLength;
    }
    else{
      endIndex = value.length;
    }

    var validValue = value.substring(0, endIndex).toString();

    if(appendEllipse){
      return validValue + ellipseText;
    }
    else{
      return validValue;
    }
  }

  static List<String> splitByToSmallCases(String value, String regex){
    List<String> values = value.toLowerCase().split(RegExp(regex));
    return List.of(values);
  }

}
